@@ -1,24 +1,18 @@
 #' Watches code and tests for changes, rerunning tests as appropriate.
 #'
+#' @description
+#' `r lifecycle::badge("superseded")`
+#'
 #' The idea behind `auto_test()` is that you just leave it running while
 #' you develop your code.  Every time you save a file it will be automatically
 #' tested and you can easily see if your changes have caused any test
-#'  failures.
+#' failures.
 #'
 #' The current strategy for rerunning tests is as follows:
 #'
 #' - if any code has changed, then those files are reloaded and all tests
 #'   rerun
 #' - otherwise, each new or modified test is run
-#'
-#' In the future, `auto_test()` might implement one of the following more
-#' intelligent alternatives:
-#'
-#' - Use codetools to build up dependency tree and then rerun tests only
-#'   when a dependency changes.
-#' - Mimic ruby's autotest and rerun only failing tests until they pass,
-#'   and then rerun all tests.
-#
 #' @seealso [auto_test_package()]
 #' @export
 #' @param code_path path to directory containing code
@@ -27,10 +21,14 @@
 #' @param env environment in which to execute test suite.
 #' @param hash Passed on to [watch()]. When FALSE, uses less accurate
 #'   modification time stamps, but those are faster for large files.
-#' @keywords debugging
-auto_test <- function(code_path, test_path, reporter = default_reporter(),
-                      env = test_env(),
-                      hash = TRUE) {
+#' @keywords internal
+auto_test <- function(
+  code_path,
+  test_path,
+  reporter = default_reporter(),
+  env = test_env(),
+  hash = TRUE
+) {
   reporter <- find_reporter(reporter)
   code_path <- normalizePath(code_path)
   test_path <- normalizePath(test_path)
@@ -63,16 +61,17 @@ auto_test <- function(code_path, test_path, reporter = default_reporter(),
   watch(c(code_path, test_path), watcher, hash = hash)
 }
 
-#' Watches a package for changes, rerunning tests as appropriate.
-#'
 #' @param pkg path to package
 #' @export
 #' @param reporter test reporter to use
 #' @param hash Passed on to [watch()].  When FALSE, uses less accurate
 #'   modification time stamps, but those are faster for large files.
-#' @keywords debugging
-#' @seealso [auto_test()] for details on how method works
-auto_test_package <- function(pkg = ".", reporter = default_reporter(), hash = TRUE) {
+#' @rdname auto_test
+auto_test_package <- function(
+  pkg = ".",
+  reporter = default_reporter(),
+  hash = TRUE
+) {
   reporter <- find_reporter(reporter)
 
   path <- pkgload::pkg_path(pkg)
@@ -84,9 +83,14 @@ auto_test_package <- function(pkg = ".", reporter = default_reporter(), hash = T
   test_path <- normalizePath(file.path(path, "tests", "testthat"))
 
   # Start by loading all code and running all tests
-  withr::local_envvar("NOT_CRAN" = "true")
+  local_assume_not_on_cran()
   pkgload::load_all(path)
-  test_dir(test_path, package = package, reporter = reporter$clone(deep = TRUE), stop_on_failure = FALSE)
+  test_dir(
+    test_path,
+    package = package,
+    reporter = reporter$clone(deep = TRUE),
+    stop_on_failure = FALSE
+  )
 
   # Next set up watcher to monitor changes
   watcher <- function(added, deleted, modified) {
@@ -106,7 +110,11 @@ auto_test_package <- function(pkg = ".", reporter = default_reporter(), hash = T
       cat("Changed code: ", paste0(basename(code), collapse = ", "), "\n")
       cat("Rerunning all tests\n")
       pkgload::load_all(path, quiet = TRUE)
-      test_dir(test_path, package = package, reporter = reporter$clone(deep = TRUE))
+      test_dir(
+        test_path,
+        package = package,
+        reporter = reporter$clone(deep = TRUE)
+      )
     } else if (length(tests) > 0) {
       # If test changes, rerun just that test
       cat("Rerunning tests: ", paste0(basename(tests), collapse = ", "), "\n")
@@ -115,7 +123,7 @@ auto_test_package <- function(pkg = ".", reporter = default_reporter(), hash = T
         test_dir = test_path,
         test_package = package,
         test_paths = tests,
-        env = env, 
+        env = env,
         reporter = reporter$clone(deep = TRUE)
       )
     }
