@@ -6,7 +6,8 @@
 #'
 #' @export
 #' @family reporters
-LocationReporter <- R6::R6Class("LocationReporter",
+LocationReporter <- R6::R6Class(
+  "LocationReporter",
   inherit = Reporter,
   public = list(
     start_test = function(context, test) {
