@@ -14,14 +14,27 @@
 "_PACKAGE"
 
 #' @import rlang
+#' @importFrom brio writeLines readLines
 #' @useDynLib testthat, .registration = TRUE
 NULL
 
-testthat_env <- new.env(parent = emptyenv())
-
+the <- new.env(parent = emptyenv())
+the$description <- character()
+the$top_level_test <- TRUE
+the$test_expectations <- 0
+the$in_check_reporter <- FALSE
 
 # The following block is used by usethis to automatically manage
 # roxygen namespace tags. Modify with care!
 ## usethis namespace: start
+#' @importFrom lifecycle deprecated
 ## usethis namespace: end
 NULL
+
+# nocov start
+
+.onLoad <- function(libname, pkgname) {
+  otel_cache_tracer()
+}
+
+# nocov end
