@@ -1,6 +1,5 @@
-context("Contexts")
-
-CountReporter <- R6::R6Class("CountReporter",
+CountReporter <- R6::R6Class(
+  "CountReporter",
   inherit = Reporter,
   public = list(
     context_i = 0,
@@ -28,10 +27,21 @@ CountReporter <- R6::R6Class("CountReporter",
 )
 
 test_that("contexts are opened, then closed", {
+  local_edition(2)
   report <- CountReporter$new()
-  test_file("context.R", report, wrap = FALSE)
-  expect_that(report$context_count, equals(2))
-  expect_that(report$context_i, equals(0))
-  expect_that(report$test_count, equals(4))
-  expect_that(report$test_i, equals(0))
+  local_description_set()
+
+  with_reporter(report, test_one_file("context.R"))
+  expect_equal(report$context_count, 2)
+  expect_equal(report$context_i, 0)
+  expect_equal(report$test_count, 4)
+  expect_equal(report$test_i, 0)
+})
+
+test_that("context_name strips prefix and extensions correctly", {
+  expect_equal(context_name("test-metrics.R"), "metrics") # uppercase
+  expect_equal(context_name("test-metrics.r"), "metrics") # lowercase
+  expect_equal(context_name("test-check.Rfile.R"), "check.Rfile") # suffix only
+  expect_equal(context_name("test-test-test.R"), "test-test") # 1st prefix only
+  expect_equal(context_name("test_metrics.R"), "metrics")
 })
